# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/admin/metering_report_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/admin/metering_report_service.proto',
  package='com.daml.ledger.api.v1.admin',
  syntax='proto3',
  serialized_options=b'\n\034com.daml.ledger.api.v1.adminB\030MeteringReportOuterClassZUgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1/admin\252\002\034Com.Daml.Ledger.Api.V1.Admin',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:com/daml/ledger/api/v1/admin/metering_report_service.proto\x12\x1c\x63om.daml.ledger.api.v1.admin\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x01\n\x18GetMeteringReportRequest\x12.\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12*\n\x02to\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02to\x12%\n\x0e\x61pplication_id\x18\x03 \x01(\tR\rapplicationId\"\xa7\x02\n\x19GetMeteringReportResponse\x12P\n\x07request\x18\x01 \x01(\x0b\x32\x36.com.daml.ledger.api.v1.admin.GetMeteringReportRequestR\x07request\x12\x66\n\x12participant_report\x18\x02 \x01(\x0b\x32\x37.com.daml.ledger.api.v1.admin.ParticipantMeteringReportR\x11participantReport\x12P\n\x16report_generation_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x14reportGenerationTime\"\xe5\x01\n\x19ParticipantMeteringReport\x12%\n\x0eparticipant_id\x18\x01 \x01(\tR\rparticipantId\x12\x37\n\tto_actual\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08toActual\x12h\n\x13\x61pplication_reports\x18\x03 \x03(\x0b\x32\x37.com.daml.ledger.api.v1.admin.ApplicationMeteringReportR\x12\x61pplicationReports\"c\n\x19\x41pplicationMeteringReport\x12%\n\x0e\x61pplication_id\x18\x01 \x01(\tR\rapplicationId\x12\x1f\n\x0b\x65vent_count\x18\x02 \x01(\x03R\neventCount2\x9e\x01\n\x15MeteringReportService\x12\x84\x01\n\x11GetMeteringReport\x12\x36.com.daml.ledger.api.v1.admin.GetMeteringReportRequest\x1a\x37.com.daml.ledger.api.v1.admin.GetMeteringReportResponseB\xae\x01\n\x1c\x63om.daml.ledger.api.v1.adminB\x18MeteringReportOuterClassZUgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V1.Adminb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_GETMETERINGREPORTREQUEST = _descriptor.Descriptor(
  name='GetMeteringReportRequest',
  full_name='com.daml.ledger.api.v1.admin.GetMeteringReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportRequest.from', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='from', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportRequest.to', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='to', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_id', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportRequest.application_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='applicationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=283,
)


_GETMETERINGREPORTRESPONSE = _descriptor.Descriptor(
  name='GetMeteringReportResponse',
  full_name='com.daml.ledger.api.v1.admin.GetMeteringReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='request', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_report', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportResponse.participant_report', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='participantReport', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report_generation_time', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportResponse.report_generation_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reportGenerationTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=581,
)


_PARTICIPANTMETERINGREPORT = _descriptor.Descriptor(
  name='ParticipantMeteringReport',
  full_name='com.daml.ledger.api.v1.admin.ParticipantMeteringReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='com.daml.ledger.api.v1.admin.ParticipantMeteringReport.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='participantId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_actual', full_name='com.daml.ledger.api.v1.admin.ParticipantMeteringReport.to_actual', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='toActual', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_reports', full_name='com.daml.ledger.api.v1.admin.ParticipantMeteringReport.application_reports', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='applicationReports', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=584,
  serialized_end=813,
)


_APPLICATIONMETERINGREPORT = _descriptor.Descriptor(
  name='ApplicationMeteringReport',
  full_name='com.daml.ledger.api.v1.admin.ApplicationMeteringReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='application_id', full_name='com.daml.ledger.api.v1.admin.ApplicationMeteringReport.application_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='applicationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_count', full_name='com.daml.ledger.api.v1.admin.ApplicationMeteringReport.event_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventCount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=914,
)

_GETMETERINGREPORTREQUEST.fields_by_name['from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETMETERINGREPORTREQUEST.fields_by_name['to'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETMETERINGREPORTRESPONSE.fields_by_name['request'].message_type = _GETMETERINGREPORTREQUEST
_GETMETERINGREPORTRESPONSE.fields_by_name['participant_report'].message_type = _PARTICIPANTMETERINGREPORT
_GETMETERINGREPORTRESPONSE.fields_by_name['report_generation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARTICIPANTMETERINGREPORT.fields_by_name['to_actual'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARTICIPANTMETERINGREPORT.fields_by_name['application_reports'].message_type = _APPLICATIONMETERINGREPORT
DESCRIPTOR.message_types_by_name['GetMeteringReportRequest'] = _GETMETERINGREPORTREQUEST
DESCRIPTOR.message_types_by_name['GetMeteringReportResponse'] = _GETMETERINGREPORTRESPONSE
DESCRIPTOR.message_types_by_name['ParticipantMeteringReport'] = _PARTICIPANTMETERINGREPORT
DESCRIPTOR.message_types_by_name['ApplicationMeteringReport'] = _APPLICATIONMETERINGREPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetMeteringReportRequest = _reflection.GeneratedProtocolMessageType('GetMeteringReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETERINGREPORTREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.admin.metering_report_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.GetMeteringReportRequest)
  })
_sym_db.RegisterMessage(GetMeteringReportRequest)

GetMeteringReportResponse = _reflection.GeneratedProtocolMessageType('GetMeteringReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETERINGREPORTRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.admin.metering_report_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.GetMeteringReportResponse)
  })
_sym_db.RegisterMessage(GetMeteringReportResponse)

ParticipantMeteringReport = _reflection.GeneratedProtocolMessageType('ParticipantMeteringReport', (_message.Message,), {
  'DESCRIPTOR' : _PARTICIPANTMETERINGREPORT,
  '__module__' : 'com.daml.ledger.api.v1.admin.metering_report_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.ParticipantMeteringReport)
  })
_sym_db.RegisterMessage(ParticipantMeteringReport)

ApplicationMeteringReport = _reflection.GeneratedProtocolMessageType('ApplicationMeteringReport', (_message.Message,), {
  'DESCRIPTOR' : _APPLICATIONMETERINGREPORT,
  '__module__' : 'com.daml.ledger.api.v1.admin.metering_report_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.ApplicationMeteringReport)
  })
_sym_db.RegisterMessage(ApplicationMeteringReport)


DESCRIPTOR._options = None

_METERINGREPORTSERVICE = _descriptor.ServiceDescriptor(
  name='MeteringReportService',
  full_name='com.daml.ledger.api.v1.admin.MeteringReportService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=917,
  serialized_end=1075,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMeteringReport',
    full_name='com.daml.ledger.api.v1.admin.MeteringReportService.GetMeteringReport',
    index=0,
    containing_service=None,
    input_type=_GETMETERINGREPORTREQUEST,
    output_type=_GETMETERINGREPORTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_METERINGREPORTSERVICE)

DESCRIPTOR.services_by_name['MeteringReportService'] = _METERINGREPORTSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/version_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import experimental_features_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_experimental__features__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/version_service.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B\030VersionServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,com/daml/ledger/api/v1/version_service.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\x32\x63om/daml/ledger/api/v1/experimental_features.proto\"9\n\x1aGetLedgerApiVersionRequest\x12\x1b\n\tledger_id\x18\x01 \x01(\tR\x08ledgerId\"\x7f\n\x1bGetLedgerApiVersionResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x46\n\x08\x66\x65\x61tures\x18\x02 \x01(\x0b\x32*.com.daml.ledger.api.v1.FeaturesDescriptorR\x08\x66\x65\x61tures\"\xa9\x02\n\x12\x46\x65\x61turesDescriptor\x12V\n\x0fuser_management\x18\x02 \x01(\x0b\x32-.com.daml.ledger.api.v1.UserManagementFeatureR\x0euserManagement\x12P\n\x0c\x65xperimental\x18\x01 \x01(\x0b\x32,.com.daml.ledger.api.v1.ExperimentalFeaturesR\x0c\x65xperimental\x12i\n\x15\x63ommand_deduplication\x18\x03 \x01(\x0b\x32\x34.com.daml.ledger.api.v1.CommandDeduplicationFeaturesR\x14\x63ommandDeduplication\"\x17\n\x15UserManagementFeature\"\x9a\x02\n\x1c\x43ommandDeduplicationFeatures\x12t\n\x1c\x64\x65\x64uplication_period_support\x18\x01 \x01(\x0b\x32\x32.com.daml.ledger.api.v1.DeduplicationPeriodSupportR\x1a\x64\x65\x64uplicationPeriodSupport\x12\x83\x01\n!participant_deduplication_support\x18\x02 \x01(\x0e\x32\x37.com.daml.ledger.api.v1.ParticipantDeduplicationSupportR\x1fparticipantDeduplicationSupport\"\xaa\x03\n\x1a\x44\x65\x64uplicationPeriodSupport\x12g\n\x0eoffset_support\x18\x01 \x01(\x0e\x32@.com.daml.ledger.api.v1.DeduplicationPeriodSupport.OffsetSupportR\roffsetSupport\x12m\n\x10\x64uration_support\x18\x02 \x01(\x0e\x32\x42.com.daml.ledger.api.v1.DeduplicationPeriodSupport.DurationSupportR\x0f\x64urationSupport\"d\n\rOffsetSupport\x12\x19\n\x15OFFSET_NATIVE_SUPPORT\x10\x00\x12\x1e\n\x1aOFFSET_CONVERT_TO_DURATION\x10\x01\x12\x18\n\x14OFFSET_NOT_SUPPORTED\x10\x02\"N\n\x0f\x44urationSupport\x12\x1b\n\x17\x44URATION_NATIVE_SUPPORT\x10\x00\x12\x1e\n\x1a\x44URATION_CONVERT_TO_OFFSET\x10\x01*\xa4\x01\n\x1fParticipantDeduplicationSupport\x12+\n\'PARTICIPANT_DEDUPLICATION_NOT_SUPPORTED\x10\x00\x12+\n\'PARTICIPANT_DEDUPLICATION_PARALLEL_ONLY\x10\x01\x12\'\n#PARTICIPANT_DEDUPLICATION_SUPPORTED\x10\x02\x32\x90\x01\n\x0eVersionService\x12~\n\x13GetLedgerApiVersion\x12\x32.com.daml.ledger.api.v1.GetLedgerApiVersionRequest\x1a\x33.com.daml.ledger.api.v1.GetLedgerApiVersionResponseB\x9c\x01\n\x16\x63om.daml.ledger.api.v1B\x18VersionServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
  ,
  dependencies=[com_dot_daml_dot_ledger_dot_api_dot_v1_dot_experimental__features__pb2.DESCRIPTOR,])

_PARTICIPANTDEDUPLICATIONSUPPORT = _descriptor.EnumDescriptor(
  name='ParticipantDeduplicationSupport',
  full_name='com.daml.ledger.api.v1.ParticipantDeduplicationSupport',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_DEDUPLICATION_NOT_SUPPORTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_DEDUPLICATION_PARALLEL_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_DEDUPLICATION_SUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1352,
  serialized_end=1516,
)
_sym_db.RegisterEnumDescriptor(_PARTICIPANTDEDUPLICATIONSUPPORT)

ParticipantDeduplicationSupport = enum_type_wrapper.EnumTypeWrapper(_PARTICIPANTDEDUPLICATIONSUPPORT)
PARTICIPANT_DEDUPLICATION_NOT_SUPPORTED = 0
PARTICIPANT_DEDUPLICATION_PARALLEL_ONLY = 1
PARTICIPANT_DEDUPLICATION_SUPPORTED = 2


_DEDUPLICATIONPERIODSUPPORT_OFFSETSUPPORT = _descriptor.EnumDescriptor(
  name='OffsetSupport',
  full_name='com.daml.ledger.api.v1.DeduplicationPeriodSupport.OffsetSupport',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFFSET_NATIVE_SUPPORT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFFSET_CONVERT_TO_DURATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFFSET_NOT_SUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1169,
  serialized_end=1269,
)
_sym_db.RegisterEnumDescriptor(_DEDUPLICATIONPERIODSUPPORT_OFFSETSUPPORT)

_DEDUPLICATIONPERIODSUPPORT_DURATIONSUPPORT = _descriptor.EnumDescriptor(
  name='DurationSupport',
  full_name='com.daml.ledger.api.v1.DeduplicationPeriodSupport.DurationSupport',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DURATION_NATIVE_SUPPORT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DURATION_CONVERT_TO_OFFSET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1271,
  serialized_end=1349,
)
_sym_db.RegisterEnumDescriptor(_DEDUPLICATIONPERIODSUPPORT_DURATIONSUPPORT)


_GETLEDGERAPIVERSIONREQUEST = _descriptor.Descriptor(
  name='GetLedgerApiVersionRequest',
  full_name='com.daml.ledger.api.v1.GetLedgerApiVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_id', full_name='com.daml.ledger.api.v1.GetLedgerApiVersionRequest.ledger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ledgerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=181,
)


_GETLEDGERAPIVERSIONRESPONSE = _descriptor.Descriptor(
  name='GetLedgerApiVersionResponse',
  full_name='com.daml.ledger.api.v1.GetLedgerApiVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='com.daml.ledger.api.v1.GetLedgerApiVersionResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='version', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='com.daml.ledger.api.v1.GetLedgerApiVersionResponse.features', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='features', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=310,
)


_FEATURESDESCRIPTOR = _descriptor.Descriptor(
  name='FeaturesDescriptor',
  full_name='com.daml.ledger.api.v1.FeaturesDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_management', full_name='com.daml.ledger.api.v1.FeaturesDescriptor.user_management', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userManagement', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experimental', full_name='com.daml.ledger.api.v1.FeaturesDescriptor.experimental', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experimental', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_deduplication', full_name='com.daml.ledger.api.v1.FeaturesDescriptor.command_deduplication', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commandDeduplication', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=610,
)


_USERMANAGEMENTFEATURE = _descriptor.Descriptor(
  name='UserManagementFeature',
  full_name='com.daml.ledger.api.v1.UserManagementFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=635,
)


_COMMANDDEDUPLICATIONFEATURES = _descriptor.Descriptor(
  name='CommandDeduplicationFeatures',
  full_name='com.daml.ledger.api.v1.CommandDeduplicationFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deduplication_period_support', full_name='com.daml.ledger.api.v1.CommandDeduplicationFeatures.deduplication_period_support', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deduplicationPeriodSupport', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_deduplication_support', full_name='com.daml.ledger.api.v1.CommandDeduplicationFeatures.participant_deduplication_support', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='participantDeduplicationSupport', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=920,
)


_DEDUPLICATIONPERIODSUPPORT = _descriptor.Descriptor(
  name='DeduplicationPeriodSupport',
  full_name='com.daml.ledger.api.v1.DeduplicationPeriodSupport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset_support', full_name='com.daml.ledger.api.v1.DeduplicationPeriodSupport.offset_support', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offsetSupport', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration_support', full_name='com.daml.ledger.api.v1.DeduplicationPeriodSupport.duration_support', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='durationSupport', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEDUPLICATIONPERIODSUPPORT_OFFSETSUPPORT,
    _DEDUPLICATIONPERIODSUPPORT_DURATIONSUPPORT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=923,
  serialized_end=1349,
)

_GETLEDGERAPIVERSIONRESPONSE.fields_by_name['features'].message_type = _FEATURESDESCRIPTOR
_FEATURESDESCRIPTOR.fields_by_name['user_management'].message_type = _USERMANAGEMENTFEATURE
_FEATURESDESCRIPTOR.fields_by_name['experimental'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_experimental__features__pb2._EXPERIMENTALFEATURES
_FEATURESDESCRIPTOR.fields_by_name['command_deduplication'].message_type = _COMMANDDEDUPLICATIONFEATURES
_COMMANDDEDUPLICATIONFEATURES.fields_by_name['deduplication_period_support'].message_type = _DEDUPLICATIONPERIODSUPPORT
_COMMANDDEDUPLICATIONFEATURES.fields_by_name['participant_deduplication_support'].enum_type = _PARTICIPANTDEDUPLICATIONSUPPORT
_DEDUPLICATIONPERIODSUPPORT.fields_by_name['offset_support'].enum_type = _DEDUPLICATIONPERIODSUPPORT_OFFSETSUPPORT
_DEDUPLICATIONPERIODSUPPORT.fields_by_name['duration_support'].enum_type = _DEDUPLICATIONPERIODSUPPORT_DURATIONSUPPORT
_DEDUPLICATIONPERIODSUPPORT_OFFSETSUPPORT.containing_type = _DEDUPLICATIONPERIODSUPPORT
_DEDUPLICATIONPERIODSUPPORT_DURATIONSUPPORT.containing_type = _DEDUPLICATIONPERIODSUPPORT
DESCRIPTOR.message_types_by_name['GetLedgerApiVersionRequest'] = _GETLEDGERAPIVERSIONREQUEST
DESCRIPTOR.message_types_by_name['GetLedgerApiVersionResponse'] = _GETLEDGERAPIVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['FeaturesDescriptor'] = _FEATURESDESCRIPTOR
DESCRIPTOR.message_types_by_name['UserManagementFeature'] = _USERMANAGEMENTFEATURE
DESCRIPTOR.message_types_by_name['CommandDeduplicationFeatures'] = _COMMANDDEDUPLICATIONFEATURES
DESCRIPTOR.message_types_by_name['DeduplicationPeriodSupport'] = _DEDUPLICATIONPERIODSUPPORT
DESCRIPTOR.enum_types_by_name['ParticipantDeduplicationSupport'] = _PARTICIPANTDEDUPLICATIONSUPPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerApiVersionRequest = _reflection.GeneratedProtocolMessageType('GetLedgerApiVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERAPIVERSIONREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetLedgerApiVersionRequest)
  })
_sym_db.RegisterMessage(GetLedgerApiVersionRequest)

GetLedgerApiVersionResponse = _reflection.GeneratedProtocolMessageType('GetLedgerApiVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERAPIVERSIONRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetLedgerApiVersionResponse)
  })
_sym_db.RegisterMessage(GetLedgerApiVersionResponse)

FeaturesDescriptor = _reflection.GeneratedProtocolMessageType('FeaturesDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESDESCRIPTOR,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.FeaturesDescriptor)
  })
_sym_db.RegisterMessage(FeaturesDescriptor)

UserManagementFeature = _reflection.GeneratedProtocolMessageType('UserManagementFeature', (_message.Message,), {
  'DESCRIPTOR' : _USERMANAGEMENTFEATURE,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.UserManagementFeature)
  })
_sym_db.RegisterMessage(UserManagementFeature)

CommandDeduplicationFeatures = _reflection.GeneratedProtocolMessageType('CommandDeduplicationFeatures', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDDEDUPLICATIONFEATURES,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.CommandDeduplicationFeatures)
  })
_sym_db.RegisterMessage(CommandDeduplicationFeatures)

DeduplicationPeriodSupport = _reflection.GeneratedProtocolMessageType('DeduplicationPeriodSupport', (_message.Message,), {
  'DESCRIPTOR' : _DEDUPLICATIONPERIODSUPPORT,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.DeduplicationPeriodSupport)
  })
_sym_db.RegisterMessage(DeduplicationPeriodSupport)


DESCRIPTOR._options = None

_VERSIONSERVICE = _descriptor.ServiceDescriptor(
  name='VersionService',
  full_name='com.daml.ledger.api.v1.VersionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1519,
  serialized_end=1663,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLedgerApiVersion',
    full_name='com.daml.ledger.api.v1.VersionService.GetLedgerApiVersion',
    index=0,
    containing_service=None,
    input_type=_GETLEDGERAPIVERSIONREQUEST,
    output_type=_GETLEDGERAPIVERSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VERSIONSERVICE)

DESCRIPTOR.services_by_name['VersionService'] = _VERSIONSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, sys, typing as _typing

from google.protobuf.descriptor import EnumDescriptor
from google.protobuf.message import Message as _Message

from .experimental_features_pb2 import ExperimentalFeatures

if sys.version_info >= (3, 8):
    from typing import Literal as _L
else:
    from typing_extensions import Literal as _L

__all__ = [
    "GetLedgerApiVersionRequest",
    "GetLedgerApiVersionResponse",
    "FeaturesDescriptor",
    "UserManagementFeature",
    "CommandDeduplicationFeatures",
    "DeduplicationPeriodSupport",
]

class ParticipantDeduplicationSupport:
    DESCRIPTOR: _typing.ClassVar[EnumDescriptor] = ...
    PARTICIPANT_DEDUPLICATION_NOT_SUPPORTED: _typing.ClassVar[_L[0]] = ...
    PARTICIPANT_DEDUPLICATION_PARALLEL_ONLY: _typing.ClassVar[_L[1]] = ...
    PARTICIPANT_DEDUPLICATION_SUPPORTED: _typing.ClassVar[_L[2]] = ...
PARTICIPANT_DEDUPLICATION_NOT_SUPPORTED = _L[0]
PARTICIPANT_DEDUPLICATION_PARALLEL_ONLY = _L[1]
PARTICIPANT_DEDUPLICATION_SUPPORTED = _L[2]


class GetLedgerApiVersionRequest(_Message):
    ledger_id: _builtins.str
    def __init__(self, *, ledger_id: _typing.Optional[_builtins.str] = ...): ...
    def HasField(self, field_name: _L["ledger_id"]) -> _builtins.bool: ...
    def ClearField(self, field_name: _L["ledger_id"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class GetLedgerApiVersionResponse(_Message):
    version: _builtins.str
    @property
    def features(self) -> FeaturesDescriptor: ...
    def __init__(self, *, version: _typing.Optional[_builtins.str] = ..., features: _typing.Optional[FeaturesDescriptor] = ...): ...
    def HasField(self, field_name: _L["version", "features"]) -> _builtins.bool: ...
    def ClearField(self, field_name: _L["version", "features"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class FeaturesDescriptor(_Message):
    @property
    def user_management(self) -> UserManagementFeature: ...
    @property
    def experimental(self) -> ExperimentalFeatures: ...
    @property
    def command_deduplication(self) -> CommandDeduplicationFeatures: ...
    def __init__(self, *, user_management: _typing.Optional[UserManagementFeature] = ..., experimental: _typing.Optional[ExperimentalFeatures] = ..., command_deduplication: _typing.Optional[CommandDeduplicationFeatures] = ...): ...
    def HasField(self, field_name: _L["user_management", "experimental", "command_deduplication"]) -> _builtins.bool: ...
    def ClearField(self, field_name: _L["user_management", "experimental", "command_deduplication"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class UserManagementFeature(_Message):
    def __init__(self): ...
    def HasField(self, field_name: _typing.NoReturn) -> _typing.NoReturn: ...
    def ClearField(self, field_name: _typing.NoReturn) -> _typing.NoReturn: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class CommandDeduplicationFeatures(_Message):
    @property
    def deduplication_period_support(self) -> DeduplicationPeriodSupport: ...
    @property
    def participant_deduplication_support(self) -> _L[0, 1, 2]: ...
    def __init__(self, *, deduplication_period_support: _typing.Optional[DeduplicationPeriodSupport] = ..., participant_deduplication_support: _typing.Optional[_L['PARTICIPANT_DEDUPLICATION_NOT_SUPPORTED', 0, 'PARTICIPANT_DEDUPLICATION_PARALLEL_ONLY', 1, 'PARTICIPANT_DEDUPLICATION_SUPPORTED', 2]] = ...): ...
    def HasField(self, field_name: _L["deduplication_period_support", "participant_deduplication_support"]) -> _builtins.bool: ...
    def ClearField(self, field_name: _L["deduplication_period_support", "participant_deduplication_support"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class DeduplicationPeriodSupport(_Message):
    @property
    def offset_support(self) -> _L[0, 1, 2]: ...
    @property
    def duration_support(self) -> _L[0, 1]: ...
    def __init__(self, *, offset_support: _typing.Optional[_L['OFFSET_NATIVE_SUPPORT', 0, 'OFFSET_CONVERT_TO_DURATION', 1, 'OFFSET_NOT_SUPPORTED', 2]] = ..., duration_support: _typing.Optional[_L['DURATION_NATIVE_SUPPORT', 0, 'DURATION_CONVERT_TO_OFFSET', 1]] = ...): ...
    def HasField(self, field_name: _L["offset_support", "duration_support"]) -> _builtins.bool: ...
    def ClearField(self, field_name: _L["offset_support", "duration_support"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...



# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/admin/user_management_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/admin/user_management_service.proto',
  package='com.daml.ledger.api.v1.admin',
  syntax='proto3',
  serialized_options=b'\n\034com.daml.ledger.api.v1.adminB\037UserManagementServiceOuterClassZUgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1/admin\252\002\034Com.Daml.Ledger.Api.V1.Admin',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:com/daml/ledger/api/v1/admin/user_management_service.proto\x12\x1c\x63om.daml.ledger.api.v1.admin\";\n\x04User\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12#\n\rprimary_party\x18\x02 \x01(\tR\x0cprimaryParty\"\xec\x02\n\x05Right\x12\x63\n\x11participant_admin\x18\x01 \x01(\x0b\x32\x34.com.daml.ledger.api.v1.admin.Right.ParticipantAdminH\x00R\x10participantAdmin\x12L\n\ncan_act_as\x18\x02 \x01(\x0b\x32,.com.daml.ledger.api.v1.admin.Right.CanActAsH\x00R\x08\x63\x61nActAs\x12O\n\x0b\x63\x61n_read_as\x18\x03 \x01(\x0b\x32-.com.daml.ledger.api.v1.admin.Right.CanReadAsH\x00R\tcanReadAs\x1a\x12\n\x10ParticipantAdmin\x1a \n\x08\x43\x61nActAs\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x1a!\n\tCanReadAs\x12\x14\n\x05party\x18\x01 \x01(\tR\x05partyB\x06\n\x04kind\"\x88\x01\n\x11\x43reateUserRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.admin.UserR\x04user\x12;\n\x06rights\x18\x02 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x06rights\")\n\x0eGetUserRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\",\n\x11\x44\x65leteUserRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"\x14\n\x12\x44\x65leteUserResponse\"\x12\n\x10ListUsersRequest\"M\n\x11ListUsersResponse\x12\x38\n\x05users\x18\x01 \x03(\x0b\x32\".com.daml.ledger.api.v1.admin.UserR\x05users\"n\n\x16GrantUserRightsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12;\n\x06rights\x18\x02 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x06rights\"p\n\x17GrantUserRightsResponse\x12U\n\x14newly_granted_rights\x18\x01 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x12newlyGrantedRights\"o\n\x17RevokeUserRightsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12;\n\x06rights\x18\x02 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x06rights\"q\n\x18RevokeUserRightsResponse\x12U\n\x14newly_revoked_rights\x18\x01 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x12newlyRevokedRights\"0\n\x15ListUserRightsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"U\n\x16ListUserRightsResponse\x12;\n\x06rights\x18\x01 \x03(\x0b\x32#.com.daml.ledger.api.v1.admin.RightR\x06rights2\xb7\x06\n\x15UserManagementService\x12\x61\n\nCreateUser\x12/.com.daml.ledger.api.v1.admin.CreateUserRequest\x1a\".com.daml.ledger.api.v1.admin.User\x12[\n\x07GetUser\x12,.com.daml.ledger.api.v1.admin.GetUserRequest\x1a\".com.daml.ledger.api.v1.admin.User\x12o\n\nDeleteUser\x12/.com.daml.ledger.api.v1.admin.DeleteUserRequest\x1a\x30.com.daml.ledger.api.v1.admin.DeleteUserResponse\x12l\n\tListUsers\x12..com.daml.ledger.api.v1.admin.ListUsersRequest\x1a/.com.daml.ledger.api.v1.admin.ListUsersResponse\x12~\n\x0fGrantUserRights\x12\x34.com.daml.ledger.api.v1.admin.GrantUserRightsRequest\x1a\x35.com.daml.ledger.api.v1.admin.GrantUserRightsResponse\x12\x81\x01\n\x10RevokeUserRights\x12\x35.com.daml.ledger.api.v1.admin.RevokeUserRightsRequest\x1a\x36.com.daml.ledger.api.v1.admin.RevokeUserRightsResponse\x12{\n\x0eListUserRights\x12\x33.com.daml.ledger.api.v1.admin.ListUserRightsRequest\x1a\x34.com.daml.ledger.api.v1.admin.ListUserRightsResponseB\xb5\x01\n\x1c\x63om.daml.ledger.api.v1.adminB\x1fUserManagementServiceOuterClassZUgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V1.Adminb\x06proto3'
)




_USER = _descriptor.Descriptor(
  name='User',
  full_name='com.daml.ledger.api.v1.admin.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='com.daml.ledger.api.v1.admin.User.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_party', full_name='com.daml.ledger.api.v1.admin.User.primary_party', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='primaryParty', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=151,
)


_RIGHT_PARTICIPANTADMIN = _descriptor.Descriptor(
  name='ParticipantAdmin',
  full_name='com.daml.ledger.api.v1.admin.Right.ParticipantAdmin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=441,
)

_RIGHT_CANACTAS = _descriptor.Descriptor(
  name='CanActAs',
  full_name='com.daml.ledger.api.v1.admin.Right.CanActAs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='party', full_name='com.daml.ledger.api.v1.admin.Right.CanActAs.party', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='party', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=475,
)

_RIGHT_CANREADAS = _descriptor.Descriptor(
  name='CanReadAs',
  full_name='com.daml.ledger.api.v1.admin.Right.CanReadAs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='party', full_name='com.daml.ledger.api.v1.admin.Right.CanReadAs.party', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='party', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=510,
)

_RIGHT = _descriptor.Descriptor(
  name='Right',
  full_name='com.daml.ledger.api.v1.admin.Right',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_admin', full_name='com.daml.ledger.api.v1.admin.Right.participant_admin', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='participantAdmin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_act_as', full_name='com.daml.ledger.api.v1.admin.Right.can_act_as', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='canActAs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_read_as', full_name='com.daml.ledger.api.v1.admin.Right.can_read_as', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='canReadAs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RIGHT_PARTICIPANTADMIN, _RIGHT_CANACTAS, _RIGHT_CANREADAS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='com.daml.ledger.api.v1.admin.Right.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=154,
  serialized_end=518,
)


_CREATEUSERREQUEST = _descriptor.Descriptor(
  name='CreateUserRequest',
  full_name='com.daml.ledger.api.v1.admin.CreateUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='com.daml.ledger.api.v1.admin.CreateUserRequest.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rights', full_name='com.daml.ledger.api.v1.admin.CreateUserRequest.rights', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rights', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=521,
  serialized_end=657,
)


_GETUSERREQUEST = _descriptor.Descriptor(
  name='GetUserRequest',
  full_name='com.daml.ledger.api.v1.admin.GetUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='com.daml.ledger.api.v1.admin.GetUserRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=659,
  serialized_end=700,
)


_DELETEUSERREQUEST = _descriptor.Descriptor(
  name='DeleteUserRequest',
  full_name='com.daml.ledger.api.v1.admin.DeleteUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='com.daml.ledger.api.v1.admin.DeleteUserRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=746,
)


_DELETEUSERRESPONSE = _descriptor.Descriptor(
  name='DeleteUserResponse',
  full_name='com.daml.ledger.api.v1.admin.DeleteUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=768,
)


_LISTUSERSREQUEST = _descriptor.Descriptor(
  name='ListUsersRequest',
  full_name='com.daml.ledger.api.v1.admin.ListUsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=788,
)


_LISTUSERSRESPONSE = _descriptor.Descriptor(
  name='ListUsersResponse',
  full_name='com.daml.ledger.api.v1.admin.ListUsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='com.daml.ledger.api.v1.admin.ListUsersResponse.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='users', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=790,
  serialized_end=867,
)


_GRANTUSERRIGHTSREQUEST = _descriptor.Descriptor(
  name='GrantUserRightsRequest',
  full_name='com.daml.ledger.api.v1.admin.GrantUserRightsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='com.daml.ledger.api.v1.admin.GrantUserRightsRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rights', full_name='com.daml.ledger.api.v1.admin.GrantUserRightsRequest.rights', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rights', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=979,
)


_GRANTUSERRIGHTSRESPONSE = _descriptor.Descriptor(
  name='GrantUserRightsResponse',
  full_name='com.daml.ledger.api.v1.admin.GrantUserRightsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='newly_granted_rights', full_name='com.daml.ledger.api.v1.admin.GrantUserRightsResponse.newly_granted_rights', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='newlyGrantedRights', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=981,
  serialized_end=1093,
)


_REVOKEUSERRIGHTSREQUEST = _descriptor.Descriptor(
  name='RevokeUserRightsRequest',
  full_name='com.daml.ledger.api.v1.admin.RevokeUserRightsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='com.daml.ledger.api.v1.admin.RevokeUserRightsRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rights', full_name='com.daml.ledger.api.v1.admin.RevokeUserRightsRequest.rights', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rights', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1095,
  serialized_end=1206,
)


_REVOKEUSERRIGHTSRESPONSE = _descriptor.Descriptor(
  name='RevokeUserRightsResponse',
  full_name='com.daml.ledger.api.v1.admin.RevokeUserRightsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='newly_revoked_rights', full_name='com.daml.ledger.api.v1.admin.RevokeUserRightsResponse.newly_revoked_rights', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='newlyRevokedRights', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1321,
)


_LISTUSERRIGHTSREQUEST = _descriptor.Descriptor(
  name='ListUserRightsRequest',
  full_name='com.daml.ledger.api.v1.admin.ListUserRightsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='com.daml.ledger.api.v1.admin.ListUserRightsRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1371,
)


_LISTUSERRIGHTSRESPONSE = _descriptor.Descriptor(
  name='ListUserRightsResponse',
  full_name='com.daml.ledger.api.v1.admin.ListUserRightsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rights', full_name='com.daml.ledger.api.v1.admin.ListUserRightsResponse.rights', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rights', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1373,
  serialized_end=1458,
)

_RIGHT_PARTICIPANTADMIN.containing_type = _RIGHT
_RIGHT_CANACTAS.containing_type = _RIGHT
_RIGHT_CANREADAS.containing_type = _RIGHT
_RIGHT.fields_by_name['participant_admin'].message_type = _RIGHT_PARTICIPANTADMIN
_RIGHT.fields_by_name['can_act_as'].message_type = _RIGHT_CANACTAS
_RIGHT.fields_by_name['can_read_as'].message_type = _RIGHT_CANREADAS
_RIGHT.oneofs_by_name['kind'].fields.append(
  _RIGHT.fields_by_name['participant_admin'])
_RIGHT.fields_by_name['participant_admin'].containing_oneof = _RIGHT.oneofs_by_name['kind']
_RIGHT.oneofs_by_name['kind'].fields.append(
  _RIGHT.fields_by_name['can_act_as'])
_RIGHT.fields_by_name['can_act_as'].containing_oneof = _RIGHT.oneofs_by_name['kind']
_RIGHT.oneofs_by_name['kind'].fields.append(
  _RIGHT.fields_by_name['can_read_as'])
_RIGHT.fields_by_name['can_read_as'].containing_oneof = _RIGHT.oneofs_by_name['kind']
_CREATEUSERREQUEST.fields_by_name['user'].message_type = _USER
_CREATEUSERREQUEST.fields_by_name['rights'].message_type = _RIGHT
_LISTUSERSRESPONSE.fields_by_name['users'].message_type = _USER
_GRANTUSERRIGHTSREQUEST.fields_by_name['rights'].message_type = _RIGHT
_GRANTUSERRIGHTSRESPONSE.fields_by_name['newly_granted_rights'].message_type = _RIGHT
_REVOKEUSERRIGHTSREQUEST.fields_by_name['rights'].message_type = _RIGHT
_REVOKEUSERRIGHTSRESPONSE.fields_by_name['newly_revoked_rights'].message_type = _RIGHT
_LISTUSERRIGHTSRESPONSE.fields_by_name['rights'].message_type = _RIGHT
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['Right'] = _RIGHT
DESCRIPTOR.message_types_by_name['CreateUserRequest'] = _CREATEUSERREQUEST
DESCRIPTOR.message_types_by_name['GetUserRequest'] = _GETUSERREQUEST
DESCRIPTOR.message_types_by_name['DeleteUserRequest'] = _DELETEUSERREQUEST
DESCRIPTOR.message_types_by_name['DeleteUserResponse'] = _DELETEUSERRESPONSE
DESCRIPTOR.message_types_by_name['ListUsersRequest'] = _LISTUSERSREQUEST
DESCRIPTOR.message_types_by_name['ListUsersResponse'] = _LISTUSERSRESPONSE
DESCRIPTOR.message_types_by_name['GrantUserRightsRequest'] = _GRANTUSERRIGHTSREQUEST
DESCRIPTOR.message_types_by_name['GrantUserRightsResponse'] = _GRANTUSERRIGHTSRESPONSE
DESCRIPTOR.message_types_by_name['RevokeUserRightsRequest'] = _REVOKEUSERRIGHTSREQUEST
DESCRIPTOR.message_types_by_name['RevokeUserRightsResponse'] = _REVOKEUSERRIGHTSRESPONSE
DESCRIPTOR.message_types_by_name['ListUserRightsRequest'] = _LISTUSERRIGHTSREQUEST
DESCRIPTOR.message_types_by_name['ListUserRightsResponse'] = _LISTUSERRIGHTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.User)
  })
_sym_db.RegisterMessage(User)

Right = _reflection.GeneratedProtocolMessageType('Right', (_message.Message,), {

  'ParticipantAdmin' : _reflection.GeneratedProtocolMessageType('ParticipantAdmin', (_message.Message,), {
    'DESCRIPTOR' : _RIGHT_PARTICIPANTADMIN,
    '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
    # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.Right.ParticipantAdmin)
    })
  ,

  'CanActAs' : _reflection.GeneratedProtocolMessageType('CanActAs', (_message.Message,), {
    'DESCRIPTOR' : _RIGHT_CANACTAS,
    '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
    # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.Right.CanActAs)
    })
  ,

  'CanReadAs' : _reflection.GeneratedProtocolMessageType('CanReadAs', (_message.Message,), {
    'DESCRIPTOR' : _RIGHT_CANREADAS,
    '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
    # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.Right.CanReadAs)
    })
  ,
  'DESCRIPTOR' : _RIGHT,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.Right)
  })
_sym_db.RegisterMessage(Right)
_sym_db.RegisterMessage(Right.ParticipantAdmin)
_sym_db.RegisterMessage(Right.CanActAs)
_sym_db.RegisterMessage(Right.CanReadAs)

CreateUserRequest = _reflection.GeneratedProtocolMessageType('CreateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.CreateUserRequest)
  })
_sym_db.RegisterMessage(CreateUserRequest)

GetUserRequest = _reflection.GeneratedProtocolMessageType('GetUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.GetUserRequest)
  })
_sym_db.RegisterMessage(GetUserRequest)

DeleteUserRequest = _reflection.GeneratedProtocolMessageType('DeleteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.DeleteUserRequest)
  })
_sym_db.RegisterMessage(DeleteUserRequest)

DeleteUserResponse = _reflection.GeneratedProtocolMessageType('DeleteUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.DeleteUserResponse)
  })
_sym_db.RegisterMessage(DeleteUserResponse)

ListUsersRequest = _reflection.GeneratedProtocolMessageType('ListUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.ListUsersRequest)
  })
_sym_db.RegisterMessage(ListUsersRequest)

ListUsersResponse = _reflection.GeneratedProtocolMessageType('ListUsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.ListUsersResponse)
  })
_sym_db.RegisterMessage(ListUsersResponse)

GrantUserRightsRequest = _reflection.GeneratedProtocolMessageType('GrantUserRightsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GRANTUSERRIGHTSREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.GrantUserRightsRequest)
  })
_sym_db.RegisterMessage(GrantUserRightsRequest)

GrantUserRightsResponse = _reflection.GeneratedProtocolMessageType('GrantUserRightsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GRANTUSERRIGHTSRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.GrantUserRightsResponse)
  })
_sym_db.RegisterMessage(GrantUserRightsResponse)

RevokeUserRightsRequest = _reflection.GeneratedProtocolMessageType('RevokeUserRightsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEUSERRIGHTSREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.RevokeUserRightsRequest)
  })
_sym_db.RegisterMessage(RevokeUserRightsRequest)

RevokeUserRightsResponse = _reflection.GeneratedProtocolMessageType('RevokeUserRightsResponse', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEUSERRIGHTSRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.RevokeUserRightsResponse)
  })
_sym_db.RegisterMessage(RevokeUserRightsResponse)

ListUserRightsRequest = _reflection.GeneratedProtocolMessageType('ListUserRightsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERRIGHTSREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.ListUserRightsRequest)
  })
_sym_db.RegisterMessage(ListUserRightsRequest)

ListUserRightsResponse = _reflection.GeneratedProtocolMessageType('ListUserRightsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERRIGHTSRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.admin.user_management_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.ListUserRightsResponse)
  })
_sym_db.RegisterMessage(ListUserRightsResponse)


DESCRIPTOR._options = None

_USERMANAGEMENTSERVICE = _descriptor.ServiceDescriptor(
  name='UserManagementService',
  full_name='com.daml.ledger.api.v1.admin.UserManagementService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1461,
  serialized_end=2284,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateUser',
    full_name='com.daml.ledger.api.v1.admin.UserManagementService.CreateUser',
    index=0,
    containing_service=None,
    input_type=_CREATEUSERREQUEST,
    output_type=_USER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUser',
    full_name='com.daml.ledger.api.v1.admin.UserManagementService.GetUser',
    index=1,
    containing_service=None,
    input_type=_GETUSERREQUEST,
    output_type=_USER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUser',
    full_name='com.daml.ledger.api.v1.admin.UserManagementService.DeleteUser',
    index=2,
    containing_service=None,
    input_type=_DELETEUSERREQUEST,
    output_type=_DELETEUSERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUsers',
    full_name='com.daml.ledger.api.v1.admin.UserManagementService.ListUsers',
    index=3,
    containing_service=None,
    input_type=_LISTUSERSREQUEST,
    output_type=_LISTUSERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GrantUserRights',
    full_name='com.daml.ledger.api.v1.admin.UserManagementService.GrantUserRights',
    index=4,
    containing_service=None,
    input_type=_GRANTUSERRIGHTSREQUEST,
    output_type=_GRANTUSERRIGHTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeUserRights',
    full_name='com.daml.ledger.api.v1.admin.UserManagementService.RevokeUserRights',
    index=5,
    containing_service=None,
    input_type=_REVOKEUSERRIGHTSREQUEST,
    output_type=_REVOKEUSERRIGHTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUserRights',
    full_name='com.daml.ledger.api.v1.admin.UserManagementService.ListUserRights',
    index=6,
    containing_service=None,
    input_type=_LISTUSERRIGHTSREQUEST,
    output_type=_LISTUSERRIGHTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_USERMANAGEMENTSERVICE)

DESCRIPTOR.services_by_name['UserManagementService'] = _USERMANAGEMENTSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import user_management_service_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2


class UserManagementServiceStub(object):
    """Experimental API to manage users and their rights for interacting with the Ledger API
    served by a participant node.

    The API roughly follows the Google API style guidelines for resource-oriented design
    (https://cloud.google.com/apis/design/resources) with the following simplifications to
    ease its implementation:

    1. List methods do not (yet) support pagination,
    as we expect to have fewer than 10k users and 1k rights per user.

    2. Resources are not named as per the Google API style guide,
    as this would be in contrast with the other Ledger API services.

    Authorization rules for the services RPCs are specified on the `RpcNameRequest`
    messages as boolean expressions over these facts:
    - ``HasRight(r)``: true iff the authenticated user has right `r`
    - ``IsAuthenticatedUser(u)``: true iff ``u`` is equal to the name of the authenticated user

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateUser = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.UserManagementService/CreateUser',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.User.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.UserManagementService/GetUser',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.GetUserRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.User.FromString,
                )
        self.DeleteUser = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.UserManagementService/DeleteUser',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.DeleteUserResponse.FromString,
                )
        self.ListUsers = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.UserManagementService/ListUsers',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUsersResponse.FromString,
                )
        self.GrantUserRights = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.UserManagementService/GrantUserRights',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.GrantUserRightsRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.GrantUserRightsResponse.FromString,
                )
        self.RevokeUserRights = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.UserManagementService/RevokeUserRights',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.RevokeUserRightsRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.RevokeUserRightsResponse.FromString,
                )
        self.ListUserRights = channel.unary_unary(
                '/com.daml.ledger.api.v1.admin.UserManagementService/ListUserRights',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUserRightsRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUserRightsResponse.FromString,
                )


class UserManagementServiceServicer(object):
    """Experimental API to manage users and their rights for interacting with the Ledger API
    served by a participant node.

    The API roughly follows the Google API style guidelines for resource-oriented design
    (https://cloud.google.com/apis/design/resources) with the following simplifications to
    ease its implementation:

    1. List methods do not (yet) support pagination,
    as we expect to have fewer than 10k users and 1k rights per user.

    2. Resources are not named as per the Google API style guide,
    as this would be in contrast with the other Ledger API services.

    Authorization rules for the services RPCs are specified on the `RpcNameRequest`
    messages as boolean expressions over these facts:
    - ``HasRight(r)``: true iff the authenticated user has right `r`
    - ``IsAuthenticatedUser(u)``: true iff ``u`` is equal to the name of the authenticated user

    """

    def CreateUser(self, request, context):
        """Create a new user, failing if it already exists.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Get the user data of a specific user or the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Delete an existing user and all its rights.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """List the all existing users.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GrantUserRights(self, request, context):
        """Grant rights to a user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeUserRights(self, request, context):
        """Revoke rights from a user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserRights(self, request, context):
        """List the set of all rights granted to a user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.CreateUserRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.User.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.GetUserRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.User.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.DeleteUserRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.DeleteUserResponse.SerializeToString,
            ),
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUsersRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUsersResponse.SerializeToString,
            ),
            'GrantUserRights': grpc.unary_unary_rpc_method_handler(
                    servicer.GrantUserRights,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.GrantUserRightsRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.GrantUserRightsResponse.SerializeToString,
            ),
            'RevokeUserRights': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeUserRights,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.RevokeUserRightsRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.RevokeUserRightsResponse.SerializeToString,
            ),
            'ListUserRights': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserRights,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUserRightsRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUserRightsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.daml.ledger.api.v1.admin.UserManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserManagementService(object):
    """Experimental API to manage users and their rights for interacting with the Ledger API
    served by a participant node.

    The API roughly follows the Google API style guidelines for resource-oriented design
    (https://cloud.google.com/apis/design/resources) with the following simplifications to
    ease its implementation:

    1. List methods do not (yet) support pagination,
    as we expect to have fewer than 10k users and 1k rights per user.

    2. Resources are not named as per the Google API style guide,
    as this would be in contrast with the other Ledger API services.

    Authorization rules for the services RPCs are specified on the `RpcNameRequest`
    messages as boolean expressions over these facts:
    - ``HasRight(r)``: true iff the authenticated user has right `r`
    - ``IsAuthenticatedUser(u)``: true iff ``u`` is equal to the name of the authenticated user

    """

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.daml.ledger.api.v1.admin.UserManagementService/CreateUser',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.CreateUserRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.daml.ledger.api.v1.admin.UserManagementService/GetUser',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.GetUserRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.daml.ledger.api.v1.admin.UserManagementService/DeleteUser',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.DeleteUserRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.DeleteUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.daml.ledger.api.v1.admin.UserManagementService/ListUsers',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUsersRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GrantUserRights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.daml.ledger.api.v1.admin.UserManagementService/GrantUserRights',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.GrantUserRightsRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.GrantUserRightsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeUserRights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.daml.ledger.api.v1.admin.UserManagementService/RevokeUserRights',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.RevokeUserRightsRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.RevokeUserRightsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserRights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.daml.ledger.api.v1.admin.UserManagementService/ListUserRights',
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUserRightsRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v1_dot_admin_dot_user__management__service__pb2.ListUserRightsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/experimental_features.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/experimental_features.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B\036ExperimentalFeaturesOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2com/daml/ledger/api/v1/experimental_features.proto\x12\x16\x63om.daml.ledger.api.v1\"\x8a\x01\n\x14\x45xperimentalFeatures\x12r\n\x18self_service_error_codes\x18\x01 \x01(\x0b\x32\x39.com.daml.ledger.api.v1.ExperimentalSelfServiceErrorCodesR\x15selfServiceErrorCodes\"#\n!ExperimentalSelfServiceErrorCodesB\xa2\x01\n\x16\x63om.daml.ledger.api.v1B\x1e\x45xperimentalFeaturesOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
)




_EXPERIMENTALFEATURES = _descriptor.Descriptor(
  name='ExperimentalFeatures',
  full_name='com.daml.ledger.api.v1.ExperimentalFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='self_service_error_codes', full_name='com.daml.ledger.api.v1.ExperimentalFeatures.self_service_error_codes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='selfServiceErrorCodes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=217,
)


_EXPERIMENTALSELFSERVICEERRORCODES = _descriptor.Descriptor(
  name='ExperimentalSelfServiceErrorCodes',
  full_name='com.daml.ledger.api.v1.ExperimentalSelfServiceErrorCodes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=254,
)

_EXPERIMENTALFEATURES.fields_by_name['self_service_error_codes'].message_type = _EXPERIMENTALSELFSERVICEERRORCODES
DESCRIPTOR.message_types_by_name['ExperimentalFeatures'] = _EXPERIMENTALFEATURES
DESCRIPTOR.message_types_by_name['ExperimentalSelfServiceErrorCodes'] = _EXPERIMENTALSELFSERVICEERRORCODES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExperimentalFeatures = _reflection.GeneratedProtocolMessageType('ExperimentalFeatures', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTALFEATURES,
  '__module__' : 'com.daml.ledger.api.v1.experimental_features_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.ExperimentalFeatures)
  })
_sym_db.RegisterMessage(ExperimentalFeatures)

ExperimentalSelfServiceErrorCodes = _reflection.GeneratedProtocolMessageType('ExperimentalSelfServiceErrorCodes', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTALSELFSERVICEERRORCODES,
  '__module__' : 'com.daml.ledger.api.v1.experimental_features_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.ExperimentalSelfServiceErrorCodes)
  })
_sym_db.RegisterMessage(ExperimentalSelfServiceErrorCodes)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
